# Top.py
A modern python module wrapper for the official [top.gg API](https://top.gg/api/docs).

**THIS MODULE IS NOT ENDORSED BY TOP.GG.** Their official package is [here](https://pypi.org/project/dblpy).


## Installation
### Dev
*without pip*
```shell
git clone https://github.com/dragdev-studios/top.py
cd top.py
python3 setup.py build && python3 setup.py install
```
*with pip*
```shell
pip install git+https://github.com/dragdev-studios/top.py
```

### Stable
pip
```shell
pip install top.py
```

git
```shell
# replace curl with wget, or whatever you use to make web requests
curl https://github.com/dragdev-studios/top.py/archive/<version>.tar.gz > top.py.tar.gz
tar -xf top.py.tar.gz
cd top.py
python3 setup.py install
```
